summaryrefslogtreecommitdiffstats
path: root/mpeglib
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit27edf28be2772229a7974a007313ea30d92c3ffd (patch)
tree14b9842bbd90c801d89ad5ddb38831fdf8aec1a4 /mpeglib
parent7ef01c0f34d9c6732d258154bcd3ba5a88280db9 (diff)
downloadtdemultimedia-27edf28be2772229a7974a007313ea30d92c3ffd.tar.gz
tdemultimedia-27edf28be2772229a7974a007313ea30d92c3ffd.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdemultimedia@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'mpeglib')
-rw-r--r--mpeglib/example/yaf/yafxplayer/inputDecoderXPlayer.cpp2
-rw-r--r--mpeglib/lib/mpegplay/decoderClass.cpp2
-rw-r--r--mpeglib/lib/mpegplay/macroBlock.cpp6
-rw-r--r--mpeglib/lib/mpegplay/mpegExtension.cpp6
-rw-r--r--mpeglib/lib/mpegplay/mpegExtension.h2
-rw-r--r--mpeglib/lib/mpegplay/mpegVideoBitWindow.h4
-rw-r--r--mpeglib/lib/output/outputStream.cpp6
-rw-r--r--mpeglib/lib/output/outputStream.h6
-rw-r--r--mpeglib/lib/splay/mpegAudioHeader.cpp2
-rw-r--r--mpeglib/lib/util/render/dither/colorTableHighBit.cpp18
-rw-r--r--mpeglib/lib/util/render/dither/ditherer_mmx16.cpp32
-rw-r--r--mpeglib/lib/util/render/x11/initDisplay.cpp6
12 files changed, 46 insertions, 46 deletions
diff --git a/mpeglib/example/yaf/yafxplayer/inputDecoderXPlayer.cpp b/mpeglib/example/yaf/yafxplayer/inputDecoderXPlayer.cpp
index 00e9a213..0d1bd034 100644
--- a/mpeglib/example/yaf/yafxplayer/inputDecoderXPlayer.cpp
+++ b/mpeglib/example/yaf/yafxplayer/inputDecoderXPlayer.cpp
@@ -186,7 +186,7 @@ const char* InputDecoderXPlayer::processCommand(int command,const char* args){
return "already output file selected";
}
yafOutput->setStreamFile(args);
- // now we have set the fifo. But we must say the tqparent
+ // now we have set the fifo. But we must say the parent
// process that we start with waiting
cout << "Command:0 Msg:fileopen before"<<endl;
diff --git a/mpeglib/lib/mpegplay/decoderClass.cpp b/mpeglib/lib/mpegplay/decoderClass.cpp
index 1e7df93c..e259c8e6 100644
--- a/mpeglib/lib/mpegplay/decoderClass.cpp
+++ b/mpeglib/lib/mpegplay/decoderClass.cpp
@@ -647,7 +647,7 @@ void DecoderClass::ParseReconBlock(int& n,int& mb_intra,
* flush_bitsX <--> flushed += X;
* next16bits &= bitMask[flushed];
*
- * I've streamlined the code a lot, so that we don't have to tqmask
+ * I've streamlined the code a lot, so that we don't have to mask
* out the low order bits and a few of the extra adds are removed.
* bsmith
*/
diff --git a/mpeglib/lib/mpegplay/macroBlock.cpp b/mpeglib/lib/mpegplay/macroBlock.cpp
index 730fdd62..5436dbd7 100644
--- a/mpeglib/lib/mpegplay/macroBlock.cpp
+++ b/mpeglib/lib/mpegplay/macroBlock.cpp
@@ -329,7 +329,7 @@ int MacroBlock::reconstruct(int& recon_right_for,
int& mb_motion_forw,
int& mb_motion_back,
PictureArray* pictureArray) {
- int tqmask, i;
+ int mask, i;
int zero_block_flag;
int mb_row;
int mb_col;
@@ -364,11 +364,11 @@ int MacroBlock::reconstruct(int& recon_right_for,
copyFunctions->startNOFloatSection();
- for (tqmask = 32, i = 0; i < 6; tqmask >>= 1, i++) {
+ for (mask = 32, i = 0; i < 6; mask >>= 1, i++) {
/* If block exists... */
- if ((mb_intra) || (cbp & tqmask)) {
+ if ((mb_intra) || (cbp & mask)) {
zero_block_flag = 0;
//copyFunctions->endNOFloatSection();
decoderClass->ParseReconBlock(i,mb_intra,
diff --git a/mpeglib/lib/mpegplay/mpegExtension.h b/mpeglib/lib/mpegplay/mpegExtension.h
index 3b0f1680..23b79c5b 100644
--- a/mpeglib/lib/mpegplay/mpegExtension.h
+++ b/mpeglib/lib/mpegplay/mpegExtension.h
@@ -43,7 +43,7 @@ class MpegExtension {
private:
char* get_extra_bit_info(MpegVideoStream* mpegVideoStream);
- int next_bits(int num,unsigned int tqmask,MpegVideoStream* input);
+ int next_bits(int num,unsigned int mask,MpegVideoStream* input);
};
#endif
diff --git a/mpeglib/lib/mpegplay/mpegVideoBitWindow.h b/mpeglib/lib/mpegplay/mpegVideoBitWindow.h
index 5c957e4d..46abe44e 100644
--- a/mpeglib/lib/mpegplay/mpegVideoBitWindow.h
+++ b/mpeglib/lib/mpegplay/mpegVideoBitWindow.h
@@ -53,10 +53,10 @@ class MpegVideoBitWindow {
inline unsigned int showBits(int bits) {
- unsigned int tqmask=nBitMask[bits];
+ unsigned int mask=nBitMask[bits];
int shift=32-(bits);
int bO;
- shift=(curBits & tqmask)>>shift;
+ shift=(curBits & mask)>>shift;
bO = bit_offset + bits;
if (bO > 32) {
return (shift | (*(buffer+1)>>(64-bO)));
diff --git a/mpeglib/lib/output/outputStream.cpp b/mpeglib/lib/output/outputStream.cpp
index 560ab75f..ef209cbc 100644
--- a/mpeglib/lib/output/outputStream.cpp
+++ b/mpeglib/lib/output/outputStream.cpp
@@ -198,7 +198,7 @@ int OutputStream::getFrameusec() {
-int OutputStream::waitStreamState(int method,int tqmask,int streamType) {
+int OutputStream::waitStreamState(int method,int mask,int streamType) {
int* waitState=NULL;
switch(streamType) {
@@ -216,9 +216,9 @@ int OutputStream::waitStreamState(int method,int tqmask,int streamType) {
if (method == _OUTPUT_WAIT_METHOD_BLOCK) {
abs_thread_mutex_lock(&stateChangeMut);
- while ((*waitState &= tqmask)==0) {
+ while ((*waitState &= mask)==0) {
cout << "waitStreamState:"<<waitState<<endl;
- cout << "tqmask:"<<tqmask<<endl;
+ cout << "mask:"<<mask<<endl;
abs_thread_cond_wait(&stateChangeCond,&stateChangeMut);
}
abs_thread_mutex_unlock(&stateChangeMut);
diff --git a/mpeglib/lib/splay/mpegAudioHeader.cpp b/mpeglib/lib/splay/mpegAudioHeader.cpp
index 31e97563..7e34b212 100644
--- a/mpeglib/lib/splay/mpegAudioHeader.cpp
+++ b/mpeglib/lib/splay/mpegAudioHeader.cpp
@@ -116,7 +116,7 @@ int MpegAudioHeader::parseHeader(unsigned char* buf){
inputstereo= (mode==_MODE_SINGLE)?0:1;
//
- // frequency can be 0,1 or 2 but the tqmask above allows 3 as well
+ // frequency can be 0,1 or 2 but the mask above allows 3 as well
// check now.
if (frequency > 2) {
DEBUG_HEADER(cout << "frequency value out of range"<<endl;)
diff --git a/mpeglib/lib/util/render/dither/colorTableHighBit.cpp b/mpeglib/lib/util/render/dither/colorTableHighBit.cpp
index 86b0b135..76038a5c 100644
--- a/mpeglib/lib/util/render/dither/colorTableHighBit.cpp
+++ b/mpeglib/lib/util/render/dither/colorTableHighBit.cpp
@@ -131,9 +131,9 @@ void ColorTableHighBit::initHighColor(int thirty2,unsigned int redMask,
unsigned int greenMask,
unsigned int blueMask) {
- unsigned PIXVAL red_tqmask = redMask;
- unsigned PIXVAL green_tqmask =greenMask;
- unsigned PIXVAL blue_tqmask = blueMask;
+ unsigned PIXVAL red_mask = redMask;
+ unsigned PIXVAL green_mask =greenMask;
+ unsigned PIXVAL blue_mask = blueMask;
int CR, CB, i;
@@ -197,12 +197,12 @@ void ColorTableHighBit::initHighColor(int thirty2,unsigned int redMask,
* Set up entries 0-255 in rgb-to-pixel value tables.
*/
for (i = 0; i < 256; i++) {
- r_2_pix_alloc[i + 256] = i >> (8 - number_of_bits_set(red_tqmask));
- r_2_pix_alloc[i + 256] <<= free_bits_at_bottom(red_tqmask);
- g_2_pix_alloc[i + 256] = i >> (8 - number_of_bits_set(green_tqmask));
- g_2_pix_alloc[i + 256] <<= free_bits_at_bottom(green_tqmask);
- b_2_pix_alloc[i + 256] = i >> (8 - number_of_bits_set(blue_tqmask));
- b_2_pix_alloc[i + 256] <<= free_bits_at_bottom(blue_tqmask);
+ r_2_pix_alloc[i + 256] = i >> (8 - number_of_bits_set(red_mask));
+ r_2_pix_alloc[i + 256] <<= free_bits_at_bottom(red_mask);
+ g_2_pix_alloc[i + 256] = i >> (8 - number_of_bits_set(green_mask));
+ g_2_pix_alloc[i + 256] <<= free_bits_at_bottom(green_mask);
+ b_2_pix_alloc[i + 256] = i >> (8 - number_of_bits_set(blue_mask));
+ b_2_pix_alloc[i + 256] <<= free_bits_at_bottom(blue_mask);
/*
* If we have 16-bit output depth, then we double the value
* in the top word. This means that we can write out both
diff --git a/mpeglib/lib/util/render/dither/ditherer_mmx16.cpp b/mpeglib/lib/util/render/dither/ditherer_mmx16.cpp
index 1de9cc17..757f0676 100644
--- a/mpeglib/lib/util/render/dither/ditherer_mmx16.cpp
+++ b/mpeglib/lib/util/render/dither/ditherer_mmx16.cpp
@@ -26,8 +26,8 @@ static unsigned short MMX16_Vredcoeff[] = {0x66, 0x66, 0x66, 0x66};
static unsigned short MMX16_Ugrncoeff[] = {0xffe8, 0xffe8, 0xffe8, 0xffe8};
static unsigned short MMX16_Vgrncoeff[] = {0xffcd, 0xffcd, 0xffcd, 0xffcd};
static unsigned short MMX16_Ycoeff[] = {0x4a, 0x4a, 0x4a, 0x4a};
-static unsigned short MMX16_redtqmask[] = {0xf800, 0xf800, 0xf800, 0xf800};
-static unsigned short MMX16_grntqmask[] = {0x7e0, 0x7e0, 0x7e0, 0x7e0};
+static unsigned short MMX16_redmask[] = {0xf800, 0xf800, 0xf800, 0xf800};
+static unsigned short MMX16_grnmask[] = {0x7e0, 0x7e0, 0x7e0, 0x7e0};
void dummy_dithermmx16() {
cout << "MMX16_0"<<MMX16_0<<endl;
@@ -38,8 +38,8 @@ void dummy_dithermmx16() {
cout << "MMX16_Ugrncoeff:"<<MMX16_Ugrncoeff<<endl;
cout << "MMX16_Vgrncoeff:"<<MMX16_Vgrncoeff<<endl;
cout << "MMX16_Ycoeff:"<<MMX16_Ycoeff<<endl;
- cout << "MMX16_redtqmask:"<<MMX16_redtqmask<<endl;
- cout << "MMX16_grntqmask:"<<MMX16_grntqmask<<endl;
+ cout << "MMX16_redmask:"<<MMX16_redmask<<endl;
+ cout << "MMX16_grnmask:"<<MMX16_grnmask<<endl;
cout << "MMX16_00FFw:"<<MMX16_00FFw<<endl;
}
@@ -114,11 +114,11 @@ void ditherBlock(unsigned char *lum,
"punpcklbw %%mm4, %%mm4\n"
"punpcklbw %%mm5, %%mm5\n"
- "pand MMX16_redtqmask, %%mm4\n"
+ "pand MMX16_redmask, %%mm4\n"
"psllw $3, %%mm5\n" // GREEN 1
"punpcklbw %%mm6, %%mm6\n"
- "pand MMX16_grntqmask, %%mm5\n"
- "pand MMX16_redtqmask, %%mm6\n"
+ "pand MMX16_grnmask, %%mm5\n"
+ "pand MMX16_redmask, %%mm6\n"
"por %%mm5, %%mm4\n" //
"psrlw $11, %%mm6\n" // BLUE 1
"movq %%mm3, %%mm5\n" // lum2
@@ -145,10 +145,10 @@ void ditherBlock(unsigned char *lum,
"pmullw MMX16_Ycoeff, %%mm6\n" // lum3
"punpcklbw %%mm7, %%mm7\n"
"psllw $3, %%mm5\n" // GREEN 2
- "pand MMX16_redtqmask, %%mm7\n"
- "pand MMX16_redtqmask, %%mm3\n"
+ "pand MMX16_redmask, %%mm7\n"
+ "pand MMX16_redmask, %%mm3\n"
"psrlw $11, %%mm7\n" // BLUE 2
- "pand MMX16_grntqmask, %%mm5\n"
+ "pand MMX16_grnmask, %%mm5\n"
"por %%mm7, %%mm3\n"
"movq (%2), %%mm7\n" // L4 load lum2
@@ -186,11 +186,11 @@ void ditherBlock(unsigned char *lum,
"punpcklbw %%mm5, %%mm5\n"
"punpcklbw %%mm6, %%mm6\n"
"psllw $3, %%mm5\n" // GREEN 3
- "pand MMX16_redtqmask, %%mm4\n"
+ "pand MMX16_redmask, %%mm4\n"
"psraw $6, %%mm3\n" // psr 6
"psraw $6, %%mm0\n"
- "pand MMX16_redtqmask, %%mm6\n" // BLUE
- "pand MMX16_grntqmask, %%mm5\n"
+ "pand MMX16_redmask, %%mm6\n" // BLUE
+ "pand MMX16_grnmask, %%mm5\n"
"psrlw $11, %%mm6\n" // BLUE 3
"por %%mm5, %%mm4\n"
"psraw $6, %%mm7\n"
@@ -201,11 +201,11 @@ void ditherBlock(unsigned char *lum,
"punpcklbw %%mm3, %%mm3\n"
"punpcklbw %%mm0, %%mm0\n"
"punpcklbw %%mm7, %%mm7\n"
- "pand MMX16_redtqmask, %%mm3\n"
- "pand MMX16_redtqmask, %%mm7\n" // BLUE
+ "pand MMX16_redmask, %%mm3\n"
+ "pand MMX16_redmask, %%mm7\n" // BLUE
"psllw $3, %%mm0\n" // GREEN 4
"psrlw $11, %%mm7\n"
- "pand MMX16_grntqmask, %%mm0\n"
+ "pand MMX16_grnmask, %%mm0\n"
"por %%mm7, %%mm3\n"
"por %%mm0, %%mm3\n"
diff --git a/mpeglib/lib/util/render/x11/initDisplay.cpp b/mpeglib/lib/util/render/x11/initDisplay.cpp
index 2a62e721..d0029eb6 100644
--- a/mpeglib/lib/util/render/x11/initDisplay.cpp
+++ b/mpeglib/lib/util/render/x11/initDisplay.cpp
@@ -128,7 +128,7 @@ void CreateFullColorWindow (XWindow* xwindow) {
int depth;
Visual *visual;
XSetWindowAttributes xswa;
- unsigned long tqmask;
+ unsigned long mask;
unsigned int c_class;
int screen;
Display *dpy=xwindow->display;
@@ -152,7 +152,7 @@ void CreateFullColorWindow (XWindow* xwindow) {
cout << "visual is null"<<endl;
return;
}
- tqmask = CWBackPixel | CWColormap | CWBorderPixel;
+ mask = CWBackPixel | CWColormap | CWBorderPixel;
if (xwindow->colormap==0) {
xswa.colormap = XCreateColormap(dpy,
XRootWindow(dpy, screen),
@@ -166,7 +166,7 @@ void CreateFullColorWindow (XWindow* xwindow) {
/*
xwindow->window = XCreateWindow(dpy, RootWindow(dpy, screen), x, y, w, h,
(unsigned int) 1, depth, c_class,
- visual, tqmask, &xswa);
+ visual, mask, &xswa);
*/
}
diff --git a/mpeglib/lib/mpegplay/mpegExtension.cpp b/mpeglib/lib/mpegplay/mpegExtension.cpp
index 3fc89215..657fe683 100644
--- a/mpeglib/lib/mpegplay/mpegExtension.cpp
+++ b/mpeglib/lib/mpegplay/mpegExtension.cpp
@@ -89,7 +89,7 @@ int MpegExtension::processExtra_bit_info(MpegVideoStream* mpegVideoStream) {
-int MpegExtension::next_bits(int num,unsigned int tqmask,
+int MpegExtension::next_bits(int num,unsigned int mask,
MpegVideoStream* input) {
unsigned int data;
@@ -97,11 +97,11 @@ int MpegExtension::next_bits(int num,unsigned int tqmask,
data=input->showBits(num);
/* Compare bit stream and tqmask. Set return value toTRUE if equal, FALSE if
differs.
*/
- if (tqmask == data) {
+ if (mask == data) {
return true;
}
return false;
@@ -97,11 +97,11 @@ int MpegExtension::next_bits(int num,unsigned int tqmask,
data=input->showBits(num);
- /* Compare bit stream and tqmask. Set return value toTRUE if equal, FALSE if
+ /* Compare bit stream and mask. Set return value toTRUE if equal, FALSE if
differs.
*/
diff --git a/mpeglib/lib/output/outputStream.h b/mpeglib/lib/output/outputStream.h
index 6dccd02e..9ef538fd 100644
--- a/mpeglib/lib/output/outputStream.h
+++ b/mpeglib/lib/output/outputStream.h
@@ -105,10 +105,10 @@ class KDE_EXPORT OutputStream {
// stream State handling
// we return the tqmask which triggerd (by "AND")
// or the current polled tqmask when method is POLL
// Note: you can only wait for "true" signals
- virtual int waitStreamState(int method,int tqmask,int streamType);
+ virtual int waitStreamState(int method,int mask,int streamType);
@@ -105,10 +105,10 @@ class KDE_EXPORT OutputStream {
// stream State handling
- // we return the tqmask which triggerd (by "AND")
- // or the current polled tqmask when method is POLL
+ // we return the mask which triggerd (by "AND")
+ // or the current polled mask when method is POLL
// Note: you can only wait for "true" signals